" System-wide vimrc file for ALTLinux distribution
"
" Maintainer:	Vim Development Team <vim@packages.altlinux.ru>
" Last change:	2003 Apr 25 by Sir Raorn <raorn@altlinux.ru>
"
" When started as "evim", evim.vim will already have done these settings.
if v:progname =~? "evim"
	finish
endif

" Use Vim settings, rather then Vi settings (much better!).
" This must be first, because it changes other options as a side effect.
set nocompatible

" allow backspacing over everything in insert mode
set backspace=indent,eol,start

set autoindent		" always set autoindenting on
set backup		" keep a backup file
set history=50		" keep 50 lines of command line history
set ruler		" show the cursor position all the time
set showcmd		" show partial command in status line

set viminfo='50,r/mnt/floppy,r/mnt/zip,%,n~/.viminfo

" Don't use Ex mode, use Q for formatting
map Q gq

" Switch syntax highlighting on, when the terminal has colors
" Also switch on highlighting the last used search pattern.
if &t_Co > 2 || has("gui_running")
	syntax on
	set hlsearch
endif

" Only do this part when compiled with support for autocommands.
if has("autocmd")

  " Enable file type detection.
  " Use the default filetype settings, so that mail gets 'tw' set to 72,
  " 'cindent' is on in C files, etc.
  " Also load indent files, to automatically do language-dependent indenting.
  filetype plugin indent on

endif " has("autocmd")

" Disable 'title' and 'icon' features in terminal modes in order to
" avoid timeouts on startup (caused by attempts to connect to X server.
" For GUI version we'll reenable them in gvimrc.
if has("title")
	set notitle
	set noicon
endif

" add key mappings for national keyboards
if has("langmap") && filereadable( $VIMRUNTIME . "/langmap/" . $LANG . ".vim" )
	exe "so " . $VIMRUNTIME . "/langmap/" . $LANG . ".vim"
endif

" Disabled for security reasons
set nomodeline
